* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******                BEGIN DATA MANIPULATION FOR EXAMPLE 6                *******.
*******                CHANGE "filesave" to your directory                  *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\14_SPLH861\861_Example6".
* Import example 5 stacked data.
GET FILE = "filesave/SPSS_Example6.sav".
DATASET NAME Example6 WINDOW=FRONT.

* Adding another version of predictors to be coded 0/1 for low/high.
RECODE freq size (-.5=0) (.5=1) INTO freq01 size01.
EXECUTE.

***********************************************************************************.
*******                       BEGIN EXAMPLE 6 MODELS                        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Example6_Output.

ECHO "SPSS Empty Means Model: No Random Intercepts (E only)".
MIXED rt BY Subject Item 
   /METHOD = REML
   /PRINT  = SOLUTION TESTCOV
  	/FIXED  = .

ECHO "SPSS Random Intercept for Subjects Model".
MIXED rt BY Subject Item 
   /METHOD = REML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = 
   /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN).

ECHO "SPSS Random Intercepts for Subjects and Items: Crossed Model".
MIXED rt BY Subject Item 
   /METHOD = REML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = 
   /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN)
   /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN).

ECHO "SPSS Random Intercepts for Subjects and Items Crossed Predictive Model;".
ECHO "Using BY statement to get cell means and comparisons via EMMEANS".
MIXED rt BY Subject Item freq01 size01  
   /METHOD = REML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = freq01 size01 freq01*size01
   /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN)
   /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
   /EMMEANS = TABLES(freq01)
   /EMMEANS = TABLES(size01)
   /EMMEANS = TABLES(freq01*size01) COMPARE(freq01)
   /EMMEANS = TABLES(freq01*size01) COMPARE(size01).

ECHO "SPSS Dropping Random Item Intercept".
MIXED rt BY Subject Item freq01 size01  
   /METHOD = REML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = freq01 size01 freq01*size01
   /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN).

ECHO "SPSS Random Slope for Effect of Freq over Subjects;".
ECHO "Removed Freq and Size from BY statement to fit random slope".
MIXED rt BY Subject Item WITH freq01 size01  
   /METHOD = REML
  	/PRINT  = SOLUTION TESTCOV
  	/FIXED  = freq01 size01 freq01*size01
   /RANDOM = INTERCEPT freq01 | SUBJECT(Subject) COVTYPE(UN)
   /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN).

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=VISIBLE  MODELVIEWS=VISIBLE
  /DOC  DOCUMENTFILE="filesave\SPSS_Example6_Output.doc"
     NOTESCAPTIONS=YES  WIDETABLES=WRAP PAGEBREAKS=YES
     PAGESIZE=INCHES(8.5, 11.0)  TOPMARGIN=INCHES(1.0)  BOTTOMMARGIN=INCHES(1.0)
     LEFTMARGIN=INCHES(1.0)  RIGHTMARGIN=INCHES(1.0).
