* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 6                *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example6"
 
* Import example 6 stacked data file 
use "$filesave\STATA_Example6.dta", clear

* Adding another version of predictors to be coded 0/1 for low/high
gen freq01 = freq
gen size01 = size
recode freq01 (-.5=0)
recode freq01 ( .5=1)
recode size01 (-.5=0)
recode size01 ( .5=1)
 
********************************************************************************
*******                      BEGIN EXAMPLE 6 MODELS                      *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example6_Output.log, replace name(STATA_Example6)

* STATA Empty Means Model: No Random Intercepts (E only)
mixed rt , variance reml, 
	estimates store Eonly	// save for LRT

* STATA Random Intercept for Subjects Model
mixed rt ,  || subject: , variance reml,
	estimates store RandSubjects,	// save for LRT
	lrtest RandSubjects Eonly		// Test random subjects
	
* STATA Random Intercept for Subjects and Items: Crossed Model
mixed rt , || _all: R.subject, ||_all: R.item, variance reml,
	estimates store RandItems,		// save for LRT
	lrtest RandItems RandSubjects	// Test random items
	
* STATA Random Intercepts for Subjects and Items Crossed Predictive Model
mixed rt ib(last).freq01 ib(last).size01 i.freq01#i.size01, ///
	|| _all: R.subject, ||_all: R.item, variance reml,
	estimates store NewRandItem, 	 // save for LRT
	margins i.freq01 i.size01,   	 // marginal means
	contrast i.freq01 i.size01,  	 // marginal mean diff tests
	margins i.freq01#i.size01,   	 // cell means
	pwcompare i.freq01#i.size01, pv  // cell mean diff tests

* STATA Dropping Random Item Intercept
mixed rt ib(last).freq01 ib(last).size01 i.freq01#i.size01, ///
	|| subject: ,  variance reml,
	estimates store NoRandItem,		// save for LRT
	lrtest NewRandItem NoRandItem	// Test random items
	margins i.freq01 i.size01,   	// marginal means
	contrast i.freq01 i.size01,  	// marginal mean diff tests
	margins i.freq01#i.size01,   	// cell means
	pwcompare i.freq01#i.size01, pv  // cell mean diff tests	

* This code should have worked (I think), but it didn't converge
 
* STATA Random Slope for Effect of Freq over Subjects
* Removed Freq and Size from i. statement to fit random slope

* mixed rt c.freq01 c.size01 c.freq01#c.size01, ///
*	|| subject: freq01, covariance(unstructured), ///
*	|| _all: R.item , noconstant variance reml,
*	estimates store RandFreq, 		// save for LRT
*	lrtest RandFreq NewRandItem 	// Test random freq	
	
 * Close log	
 log close STATA_Example6

